"""
Holds the version information for the package
"""

__copyright__ = "Copyright (c) 2024 Benjamin P. Trachtenberg"
__status__ = "prod"
__version_info__ = (0, 1, 0)
__version__ = ".".join(map(str, __version_info__))
